<TS language="la" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Crea novam inscriptionem</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novus</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copia inscriptionem iam selectam in latibulum systematis</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Transcribe</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;laude</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Dele active selectam inscriptionem ex enumeratione</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Insere inscriptionem vel titulum ut quaeras</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exporta data in hac tabella in plicam</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exporta</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Dele</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Hae sunt inscriptiones mittendi pensitationes.  Semper inspice quantitatem et inscriptionem accipiendi antequam nummos mittis.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Copia Inscriptionem</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copia &amp;Titulum</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Muta</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Exporta Index Inscriptionum</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Comma Separata Plica (*.csv)</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Titulus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Inscriptio</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nullus titulus)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialogus Tesserae</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Insere tesseram</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova tessera</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Itera novam tesseram</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Ostende tesseram</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Cifra cassidile</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Huic operationi necesse est tessera cassidili tuo ut cassidile reseret.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Resera cassidile</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Huic operationi necesse est tessera cassidili tuo ut cassidile decifret.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Decifra cassidile</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Muta tesseram</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirma cifrationem cassidilis</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Monitio: Si cassidile tuum cifras et tesseram amittis, tu &lt;b&gt;AMITTES OMNES TUOS NUMMOS BITOS&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Certusne es te velle tuum cassidile cifrare?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Cassidile cifratum</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>GRAVE: Oportet ulla prioria conservata quae fecisti de plica tui cassidilis reponi a nove generata cifrata plica cassidilis.  Propter securitatem, prioria conservata de plica non cifrata cassidilis inutilia fiet simul atque incipis uti novo cifrato cassidili.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Cassidile cifrare abortum est</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Cassidile cifrare abortum est propter internum errorem.  Tuum cassidile cifratum non est.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Tesserae datae non eaedem sunt.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Cassidile reserare abortum est.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Tessera inserta pro cassidilis decifrando prava erat.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Cassidile decifrare abortum est.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Tessera cassidilis successa est in mutando.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Monitio: Litterae ut capitales seratae sunt!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation>Interdictum usque ad</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signa &amp;nuntium...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Synchronizans cum rete...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Summarium</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Monstra generale summarium cassidilis</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transactiones</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Inspicio historiam transactionum</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>E&amp;xi</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Exi applicatione</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;De %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Monstra informationem de %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informatio de &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Monstra informationem de Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Optiones</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Cifra Cassidile...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Conserva Cassidile...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Muta tesseram...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Aperi &amp;URI...</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>Creare Cassidilium</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>Creare novum cassidilium</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Cassidile:</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Recreans indicem frustorum in disco...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Mitte nummos ad inscriptionem Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Conserva cassidile in locum alium</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Muta tesseram utam pro cassidilis cifrando</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifica nuntium...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Mitte</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Accipe</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Monstra/Occulta</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Monstra vel occulta Fenestram principem</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Cifra claves privatas quae cassidili tui sunt</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Signa nuntios cum tuis inscriptionibus Bitcoin ut demonstres te eas possidere</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Verifica nuntios ut certus sis eos signatos esse cum specificatis inscriptionibus Bitcoin</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plica</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuratio</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Auxilium</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Tabella instrumentorum "Tabs"</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>Optiones mandati initiantis</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Creans indicem frustorum in disco...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 post</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Postremum acceptum frustum generatum est %1 abhinc.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transactiones post hoc nondum visibiles erunt.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Monitio</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informatio</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Recentissimo</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>Aperi terminalem debug et diagnosticalem</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenestra</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Persequens...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transactio missa</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transactio incipiens</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Cassidile &lt;b&gt;cifratum&lt;/b&gt; est et iam nunc &lt;b&gt;reseratum&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Cassidile &lt;b&gt;cifratum&lt;/b&gt; est et iam nunc &lt;b&gt;seratum&lt;/b&gt;</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation>Error fatalis accidit.  %1 nondum pergere tute potest, et exibit.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Bytes:</source>
        <translation>Octecti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Quantitas:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantitas</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dies</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmatum</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia quantitatem</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Copia inscriptionem</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Copia titulum</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Copia quantitatem</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Copia transactionis ID</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nullus titulus)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>Cassidile</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Cifra Cassidile</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Muta Inscriptionem</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Titulus</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Inscriptio</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nova inscriptio mittendi</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Muta inscriptionem accipiendi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Muta inscriptionem mittendi</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation>Inscriptio inserta "%1" non valida inscriptio Bitcoin est.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Non potuisse cassidile reserare</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Generare novam clavem abortum est.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>versio</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished">De %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Optiones mandati initiantis</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>MempoolStats</name>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Schema</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation type="unfinished">ignotum...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Hora postremi frusti</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Type</source>
        <comment>NetWatch: Type header</comment>
        <translation>Typus</translation>
    </message>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Inscriptio</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Glutina inscriptionem ex latibulo</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Optiones</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Princeps</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Reconstitue omnes optiones clientis ad praedefinita.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Reconstitue Optiones</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Rete</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>Cassidile</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Aperi per se portam clientis Bitcoin in itineratore.  Hoc tantum effectivum est si itineratrum tuum supportat UPnP et id activum est.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Designa portam utendo &amp;UPnP</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>&amp;IP vicarii:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Porta:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Porta vicarii (e.g. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenestra</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Monstra tantum iconem in tabella systematis postquam fenestram minifactam est.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minifac in tabellam systematis potius quam applicationum</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inifac ad claudendum</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;UI</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Lingua monstranda utenti:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unita qua quantitates monstrare:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Selige praedefinitam unitam subdivisionis monstrare in interfacie et quando nummos mittere</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancella</translation>
    </message>
    <message>
        <source>default</source>
        <translation>praedefinitum</translation>
    </message>
    <message>
        <source>Bitcoin Core</source>
        <translation>Bitcoin Nucleus</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Confirma optionum reconstituere</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Inscriptio vicarii tradita non valida est.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Schema</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Monstrata informatio fortasse non recentissima est.  Tuum cassidile per se synchronizat cum rete Bitcoin postquam conexio constabilita est, sed hoc actio nondum perfecta est.</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Immatura:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation>Fossum pendendum quod nondum maturum est</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Claude</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Cannot start bitcoin: click-to-pay handler</source>
        <translation>Bitcoin incipere non potest: cliccare-ad-pensandum handler</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Tractatio URI</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Type</source>
        <translation>Typus</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Quantitas</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ignotum</translation>
    </message>
    <message>
        <source>Blk</source>
        <comment>Tx Watch: Block type abbreviation</comment>
        <translation>Fsm</translation>
    </message>
    <message>
        <source>Txn</source>
        <comment>Tx Watch: Transaction type abbreviation</comment>
        <translation>Tso</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>Resultato URI nimis longo, conare minuere verba pro titulo / nuntio.</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Error codificandi URI in codicem QR.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Salva codicem QR</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Versio clientis</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informatio</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Tempus initiandi</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Numerus conexionum</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Catena frustorum</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Cassidile: </translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Hora postremi frusti</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Aperi</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Terminale</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Debug catalogi plica</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Vacuefac terminale</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Ad</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Ab</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;Copia inscriptionem</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">ignotum</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>Quantitas:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Titulus:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>Nuntius:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Copia inscriptionem</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Copia titulum</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Copia quantitatem</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Non potuisse cassidile reserare</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Inscriptio:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Quantitas:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Titulus:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Nuntius:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Cassidile:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Copia Inscriptionem</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dies</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Titulus</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Nuntius</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nullus titulus)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Mitte Nummos</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation type="unfinished">Lectenda...</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Inopia nummorum</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Octecti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Quantitas:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Transactionis merces:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Mitte pluribus accipientibus simul</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Adde &amp;Accipientem</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Vacuefac &amp;Omnia</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Pendendum:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirma actionem mittendi</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Mitte</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia quantitatem</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transactionis merces</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirma mittendum nummorum</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Mitte</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Oportet quantitatem ad pensandum maiorem quam 0 esse.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Quantitas est ultra quod habes.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Quantitas est ultra quod habes cum merces transactionis %1 includitur.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nullus titulus)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Quantitas:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Pensa &amp;Ad:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Titulus:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Glutina inscriptionem ex latibulo</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Nuntius:</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Pensa Ad:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Signationes - Signa / Verifica nuntium</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Signa Nuntium</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Glutina inscriptionem ex latibulo</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Insere hic nuntium quod vis signare</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Signatio</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copia signationem in latibulum systematis</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Bitcoin address</source>
        <translation>Signa nuntium ut demonstres hanc inscriptionem Bitcoin a te possessa esse</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Signa &amp;Nuntium</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Reconstitue omnes campos signandi nuntii</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Vacuefac &amp;Omnia</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifica Nuntium</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Bitcoin address</source>
        <translation>Verifica nuntium ut cures signatum esse cum specifica inscriptione Bitcoin</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation>Verifica &amp;Nuntium</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Reconstitue omnes campos verificandi nuntii</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Clicca "Signa Nuntium" ut signatio generetur</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Inscriptio inserta non valida est.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Sodes inscriptionem proba et rursus conare.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Inserta inscriptio clavem non refert.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Cassidilis reserare cancellatum est.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Clavis privata absens est pro inserta inscriptione.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Nuntium signare abortum est.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Nuntius signatus.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Signatio decodificari non potuit.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Sodes signationem proba et rursus conare.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Signatio non convenit digesto nuntii</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Nuntium verificare abortum est.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Nuntius verificatus.</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Open until %1</source>
        <translation>Apertum donec %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/non confirmata</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 confirmationes</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dies</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fons</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>Generatum</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Ab</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ignotum</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Ad</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>inscriptio propria</translation>
    </message>
    <message>
        <source>label</source>
        <translation>titulus</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Creditum</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>non acceptum</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debitum</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transactionis merces</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Cuncta quantitas</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Nuntius</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Annotatio</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>ID transactionis</translation>
    </message>
    <message>
        <source>Debug information</source>
        <translation>Informatio de debug</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transactio</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation>Lectenda</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantitas</translation>
    </message>
    <message>
        <source>true</source>
        <translation>verum</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falsum</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Haec tabula monstrat descriptionem verbosam transactionis</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dies</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typus</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Titulus</translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Apertum donec %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confirmatum (%1 confirmationes)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generatum sed non acceptum</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Acceptum cum</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Acceptum ab</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Missum ad</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pensitatio ad te ipsum</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Fossa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nullus titulus)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Status transactionis.  Supervola cum mure ut monstretur numerus confirmationum.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Dies et tempus quando transactio accepta est.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Typus transactionis.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Quantitas remota ex pendendo aut addita ei.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Omne</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hodie</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Hac hebdomade</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Hoc mense</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Postremo mense</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Hoc anno</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Intervallum...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Acceptum cum</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Missum ad</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Fossa</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Alia</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Quantitas minima</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Copia inscriptionem</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Copia titulum</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Copia quantitatem</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Copia transactionis ID</translation>
    </message>
    <message>
        <source>&amp;Edit label</source>
        <translation type="unfinished">&amp;Muta titulum</translation>
    </message>
    <message>
        <source>&amp;Show transaction details</source>
        <translation type="unfinished">&amp;Monstra particularia transactionis</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Comma Separata Plica (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmatum</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dies</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typus</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Titulus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Inscriptio</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Intervallum:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>ad</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>Creare novum casidillium</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Mitte Nummos</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exporta</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exporta data in hac tabella in plicam</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Conserva cassidile</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Data cassidilis (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Conservare abortum est.</translation>
    </message>
    <message>
        <source>Backup Successful</source>
        <translation>Successum in conservando</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancella</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>This is a pre-release test build - use at your own risk - do not use for mining or merchant applications</source>
        <translation>Hoc est prae-dimittum experimentala aedes - utere eo periculo tuo proprio - nolite utere fodendo vel applicationibus mercatoriis</translation>
    </message>
    <message>
        <source>Cannot resolve -%s address: '%s'</source>
        <translation>Non posse resolvere -%s inscriptionem: '%s'</translation>
    </message>
    <message>
        <source>Corrupted block database detected</source>
        <translation>Corruptum databasum frustorum invenitur</translation>
    </message>
    <message>
        <source>Do you want to rebuild the block database now?</source>
        <translation>Visne reficere databasum frustorum iam?</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation>Error initiando databasem frustorum</translation>
    </message>
    <message>
        <source>Error initializing wallet database environment %s!</source>
        <translation>Error initiando systematem databasi cassidilis %s!</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation>Error legendo frustorum databasem</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation>Error aperiendo databasum frustorum</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Non potuisse auscultare in ulla porta.  Utere -listen=0 si hoc vis.</translation>
    </message>
    <message>
        <source>Loading P2P addresses...</source>
        <translation>Legens p2p inscriptiones...</translation>
    </message>
    <message>
        <source>Not enough file descriptors available.</source>
        <translation>Inopia descriptorum plicarum.</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>Verificante frusta...</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Signandum transactionis abortum est</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Magnitudo transactionis nimis parva</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Transactio nimis magna</translation>
    </message>
    <message>
        <source>Verifying wallet(s)...</source>
        <translation>Verificante cassidilem...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Ignotum rete specificatum in -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Inopia nummorum</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Legens indicem frustorum...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Legens cassidile...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Iterum perlegens...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Completo lengendi</translation>
    </message>
</context>
</TS>